"""
scale_range_utils.py

Contains utility functions for batch updating scale ranges of one or more Layer Definitions in a given folder
"""

def FixScaleRangesMinMax(conn, folder, min, max):
    """
    Modifies the first scale range of all Layer Definitions under the specified folder to the specified
    minimum and Mmximum scales
    """
    resList = conn.ResourceService.GetRepositoryResources(folder, "LayerDefinition")
    for child in resList.Children:
        ldf = conn.ResourceService.GetResource(child.ResourceId)
        print "Fixing: %s" % (child.ResourceId)
        # vsr is a IVectorScaleRange instance
        vsr = ldf.SubLayer.GetScaleRangeAt(0)
        vsr.MinScale = min
        # MinScale is a nullable property, so you also need to set the respective MinScaleSpecified property to true
        # in order for this change to be persisted
        vsr.MinScaleSpecified = True
        vsr.MaxScale = max
        # MaxScale is a nullable property, so you also need to set the respective MaxScaleSpecified property to true
        # in order for this change to be persisted
        vsr.MaxScaleSpecified = True
        # Save the changes back
        conn.ResourceService.SaveResource(ldf)
        print "Scale range set to [%d, %d]" % (min, max)
        print "Saved: %s" % (child.ResourceId)

def FixScaleRangesZeroToMax(conn, folder, max):
    """
    Modifies the first scale range of all Layer Definitions under the specified folder to the specified
    maximum scale. The minimum scale is un-set (ie. Set to 0)
    """
    resList = conn.ResourceService.GetRepositoryResources(folder, "LayerDefinition")
    for child in resList.Children:
        ldf = conn.ResourceService.GetResource(child.ResourceId)
        print "Fixing: %s" % (child.ResourceId)
        # vsr is a IVectorScaleRange instance
        vsr = ldf.SubLayer.GetScaleRangeAt(0)
        # MinScale is a nullable property, so to "remove" this property from serialization back to XML, you have to set
        # the respective MinScaleSpecified property to false
        vsr.MinScaleSpecified = False
        vsr.MaxScale = max
        # MaxScale is a nullable property, so you also need to set the respective MaxScaleSpecified property to true
        # in order for this change to be persisted
        vsr.MaxScaleSpecified = True
        # Save the changes back
        conn.ResourceService.SaveResource(ldf)
        print "Scale range set to [0, %d]" % (max)
        print "Saved: %s" % (child.ResourceId)

def FixScaleRangesMinToInfinity(conn, folder, min):
    """
    Modifies the first scale range of all Layer Definitions under the specified folder to the specified
    minimum scale. The maximum scale is un-set (ie. Set to infinity)
    """
    resList = conn.ResourceService.GetRepositoryResources(folder, "LayerDefinition")
    for child in resList.Children:
        ldf = conn.ResourceService.GetResource(child.ResourceId)
        print "Fixing: %s" % (child.ResourceId)
        # vsr is a IVectorScaleRange instance
        vsr = ldf.SubLayer.GetScaleRangeAt(0)
        vsr.MinScale = min
        # MinScale is a nullable property, so you also need to set the respective MinScaleSpecified property to true
        # in order for this change to be persisted
        vsr.MinScaleSpecified = True
        # MaxScale is a nullable property, so to "remove" this property from serialization back to XML, you have to set
        # the respective MaxScaleSpecified property to false
        vsr.MaxScaleSpecified = False
        conn.ResourceService.SaveResource(ldf)
        print "Scale range set to [%d, Infinity]" % min
        print "Saved: %s" % (child.ResourceId)

def FixScaleRangesZeroToInfinity(conn, folder):
    """
    Modifies the first scale range of all Layer Definitions under the specified folder to [0, Infinity]
    """
    resList = conn.ResourceService.GetRepositoryResources(folder, "LayerDefinition")
    for child in resList.Children:
        ldf = conn.ResourceService.GetResource(child.ResourceId)
        print "Fixing: %s" % (child.ResourceId)
        # vsr is a IVectorScaleRange instance
        vsr = ldf.SubLayer.GetScaleRangeAt(0)
        # MinScale is a nullable property, so to "remove" this property from serialization back to XML, you have to set
        # the respective MinScaleSpecified property to false
        vsr.MinScaleSpecified = False
        # MaxScale is a nullable property, so to "remove" this property from serialization back to XML, you have to set
        # the respective MaxScaleSpecified property to false
        vsr.MaxScaleSpecified = False
        conn.ResourceService.SaveResource(ldf)
        print "Scale range set to default [0, Infinity]"
        print "Saved: %s" % (child.ResourceId)